# The Young Supernova Experiment: Public Data Release 1 (YSE DR1) Light Curves

This is the official Zenodo data release of the Young Supernova Experiment Public Data Release 1 (YSE DR1) light curves associated with the paper, *`"The Young Supernova Experiment Data Release 1 (YSE~DR1): Light Curves and Photometric Classification of 1975 Supernovae"*. 

## Description

YSE DR1 is comprised of processed multi-color Pan-STARRS1 (PS1)-*griz* and Zwicky Transient Facility (ZTF)-*gr* photometry light curve filesin the SNANA data format of 1975 transients with host galaxy associations, redshifts, spectroscopic/photometric classifications, and additional data products from November 24th, 2019 to December 20, 2021. See Aleo et al. (2022) for details.

"yse_dr1_zenodo.tar.gz" -- All light curve data with no cut on signal to noise (S/N).

"yse_dr1_zenodo_snr_geq_4.tar.gz" -- All light curve data with S/N >= 4. This can be used to recreate the analysis in Aleo et al. (2022).

"parsnip_results_for_ysedr1_table_A1_full_for_online" -- The full version of Table~C2 in Aleo et al. (2022). The full ParSNIP (tertiary classification) results for YSE DR1.

## SNANA Header

The SNANA header contains 40 keys:

* **SURVEY**: This will always be "YSE" (Young Supernova Experiment)
* **SNID**:  This will be always be the year followed by 1-4 letters depending on date of discovery. e.g. "2020abim"
* **otherID**:  This will be always be blank.
* **IAUC**:    This will always be "UNKNOWN". IAU names are "SN" or "AT" followed by the SNID.
* **RA**:  Event RA in degrees
* **DECL**:  Event DEC in degrees
* **MWEBV**:  Milky Way reddening, estimated using Schlafly & Finkbeiner (2011). 
* **REDSHIFT_FINAL**:  The best available redshift measurement, in preference by the spectroscopic redshift of the SN, spectroscopic redshift of the (vetted) host galaxy, or photo-*z* estimate. Error will always be listed as 0.005 for spec-*z* of the SN or host-*z*. Users are urged to check Aleo et al. (2022) to determine which redshift measurements are reliable. Parentheses will show source of redshift used. Redshift is in the heliocentric frame.
* **PHOTO_Z**:  The best guess photo-*z* from Easy PhotoZ and the absolute magnitude probability. Parentheses will show if the photo-*z* was calculated with a posterior estimate of the redshift probability distribution from the Easy PhotoZ PS1 host association "(W/ POSTERIOR)" or with a uniform distribution  "(W/O POSTERIOR)".  See details in Aleo et al. (2022), section 5.3-5.4. Redshift is in the heliocentric frame.
* **VETTED_PSO_NAME**:  The Pan-STARRS object name for the vetted host galaxy (if available).
* **VETTED_PS1_OBJID**:  The Pan-STARRS object ID for the vetted host galaxy (if available).
* **VETTED_HOST_GALAXY_STATUS**:  The method by which the vetted host galaxy was determined. "GS" -- Association from and agreed upon by GHOST (Gagliano et al. 2021) and Sherlock codes (1428 objects); "G" -- GHOST only (324 objects); "S" -- Sherlock only (97 objects); "N" -- No good association from either code. Association was manually determined (64 objects). "H" -- Hostless (58 objects); "X" -- Ambiguous association (e.g., can be one of several hosts, 4 objects).
* **SN_OFFSET_TO_VETTED_HOST_GALAXY_CENTER**: The angular separation (arcsec) between the reported SN coordinates and its vetted host's NASA/IPAC Extragalactic Database (NED) coordinates (if available).
* **VETTED_HOST_GALAXY_COORDS(RA, DECL)[deg]**: The (RA, DEC) of the vetted host galaxy in degrees. 
* **VETTED_HOST_GALAXY_NAME**: The name of the vetted host galaxy name according to the NED catalog using the coordinates in VETTED_HOST_GALAXY_COORDS(RA, DECL)[deg] with a 6 arcsec crossmatch (if available). This often includes SDSS and WISEA catalog names.
* **VETTED_HOST_GALAXY_REDSHIFT**: The spectroscopic redshift of the vetted host galaxy name according to the NED catalog using the coordinates in VETTED_HOST_GALAXY_COORDS(RA, DECL)[deg] with a 6 arcsec crossmatch (if available). If the returned NED query found a photometric redshift, we used the VETTED_HOST_GALAXY_NAME and VETTED_HOST_GALAXY_COORDS(RA, DECL)[deg] but did not use the returned  photometric redshift. We favor our photo-*z*estimate instead. Redshift is in the heliocentric frame.
* **SEARCH_PEAKMJD**: Discovery date of event in MJD.
* **SEARCH_LOGMASS**: Will always be "-99.0000 +- -99.0000". 
* **PEAK_ABS_MAG**: The peak absolute magnitude (not corrected for dust extinction), only calculated if the source of REDSHIFT_FINAL is a spectroscopic-*z* of the SN or spectroscopic-*z* of the host galaxy. Assumes a flat LambdaCDM cosmology with *H_0* = 70 km/sec/Mpc, *Omega_m* = 0.3.
* **SPEC_CLASS**: The best spectroscopic classification (if available). The majority are adopted from TNS. Table 7 in Aleo et al. (2022) lists any deviations from TNS/ATEL.
* **SPEC_CLASS_BROAD**: The SPEC_CLASS recasted into one of 4 categories for our validation set: SN Ia, SN II, SN Ibc, Other. 
 > SN Ia (including subtypes SN Ia-SC, SN Ia-CSM, SN Ia-91T-like, SN Ia-91bg-like. 314 objects);
 > SN II (including subtypes SN IIn, SN IIb. 120 objects);
 > SN Ibc (including subtypes SN Ib-pec, SN Ic, SN Ic-BL, SN Ib, SN Ibn. 38 objects);
 > Other (including types TDE, SLSN-I, SLSN-II, SN (no distinction), SN Iax, LRN, LBV. 20 objects).
* **PARSNIP_PRED**: The prediction from our ParSNIP photometric classifier (using the PHOTO_Z value, and light curves with S/N >= 4). Is of class: SN Ia, SN II, or SN Ibc. 
* **PARSNIP_CONF**: The confidence score of **PARSNIP_PRED** from our ParSNIP photometric classifier. Ranges from 0-100 (in percent).
* **PARSNIP_S1**: Value and error of the ParSNIP *s_1* intrinsic latent parameter embedding.
* **PARSNIP_S2**: Value and error of the ParSNIP *s_2* intrinsic latent parameter embedding.
* **PARSNIP_S3**: Value and error of the ParSNIP *s_3* intrinsic latent parameter embedding.
* **SUPERRAENN_PRED**: The prediction from the SuperRAENN photometric classifier from Villar et al. (2020) (using the PHOTO_Z value, and lightcurves with S/N >= 4). Is of class: SN Ia, SN II, or SN Ibc. 
* **SUPERRAENN_CONF**: The confidence score of PARSNIP_PRED from the SuperRAENN photometric classifier from Villar et al. (2020). Ranges from 0-100 (in percent).
* **SET_ZTF_FP**: The zeropoint used for the ZTF forced photometry. Always set to 27.5.
* **PEAK_SNR**: The maximum S/N value from the associated light curve.
* **MAX_MJD_GAP**: The maximum gap in days between two observation epochs (not including observing season gaps >= 100 days).
* **NOBS_BEFORE_PEAK**: Number of observation epochs before the epoch of peak apparent magnitude (across all passbands).
* **NOBS_TO_PEAK**: Number of observation epochs up to including the epoch of peak apparent magnitude (across all passbands). Always NOBS_BEFORE_PEAK + 1.
* **NOBS_AFTER_PEAK**: Number of observation epochs after the epoch of peak apparent magnitude (across all passbands). Always NOBS_AFTER_MASK - NOBS_TO_PEAK.
* **SEARCH_PEAKMAG**: The peak apparent magnitude of the light curve (across all passband).
* **SEARCH_PEAKFLT**: The filter corresponding to the SEARCH_PEAKMAG value.
* **PEAKMAG_YSE-r/ZTF-r(Y)**: The peak apparent magnitude in the *r* band (YSE, ZTF), if available.
* **PEAKFLT_YSE-r/ZTF-r(Y)**: The filter corresponding to the PEAKMAG_YSE-r/ZTF-r(Y) value, if available; r=PS1-*r*, Y=ZTF-*r*.
* **FILTERS**: Observed filters for the corresponding light curve. g, r, i or z for PS1-*griz*, respectively; X for ZTF-*g*; Y for ZTF-*r*. Order can vary.
* **MASK_USED**: Quality cuts used to produce the corresponding light curve. Always Not NA Mag, FLUXCALERR > 0, MAGERR <= 1.5, SNR >= 0 (if using yse_dr1_zenodo.tar.gz) / SNR >= 4 (if using yse_dr1_zenodo_snr_geq_4.tar.gz) PM_PEAKMJD = 757, FLAG = 0x00. Quality cuts are: no negative flux measurements. FLUXCALERR value is always > 0.  MAGERR value is always <= 1.5. S/N is always at least 0 (if using yse_dr1_zenodo.tar.gz) or 4 (if using yse_dr1_zenodo_snr_geq_4.tar.gz). Light curve is contains data +/- 757 days from its peak apparent magnitude. Only take data whose quality flags are 0x00.
* **NOBS_AFTER_MASK**: The number of observation epochs in the light curve after applying MASK_USED.
* **NVAR**: The number of variables in the light curve. Always "8".

**Note:** If there is no appropriate data for the SN entry above, we use -99.0 or nan as default. E.g. If there is no apparent host galaxy (hostless association), the VETTED_HOST_GALAXY_COORDS(RA, DECL)[deg] will be (-99.0, -99.0), and so on.

## SNANA Columns

The SNANA data contains 8 columns:

* **MJD**: MJD of observation
* **FLT**: Filter of observation (g, r, i or z for PS1-*griz*, respectively; X for ZTF-*g*; Y for ZTF-*r*)
* **FIELD**: This will be "NULL" (YSE observations) or a number (ZTF observations).
* **FLUXCAL**: Measured difference flux. In AB magnitudes, calculated using a zeropoint of 27.5.
* **FLUXCALERR**: Flux error    
* **MAG**: Magnitude (AB). Calculated using a zeropoint of 27.5.
* **MAGERR**: Magnitude error
* **FLAG**: Quality of observation. Will always be "0x00".

## Reading data

Data can be read in through a custom function. Another popular option is the *sncosmo.read_snana_ascii* function from the SNCosmo astronomy Python package (See https://sncosmo.readthedocs.io/en/stable/index.html for details).

## Contact

If you have any questions about this data set, please reach out to Patrick D. Aleo at paleo2@illinois.edu.
